@@ -88,7 +88,7 @@ assign("B4", NULL, envir = ct_env)
 assign("B5", NULL, envir = ct_env)
 assign("EB02", NULL, envir = ct_env)
 assign("EB10", NULL, envir = ct_env)
-assign("EB10s", NULL, envir = ct_env)
+assign("EB10S", NULL, envir = ct_env)
 assign("EB", NULL, envir = ct_env)
 assign("H0", NULL, envir = ct_env)
 assign("H1", NULL, envir = ct_env)
@@ -104,6 +104,10 @@ assign("S3", NULL, envir = ct_env)
 assign("S4", NULL, envir = ct_env)
 assign("SS", NULL, envir = ct_env)
 assign("mode_of_transport", NULL, envir = ct_env)
+assign("mode_of_supply", NULL, envir = ct_env)
+assign("available_variables", NULL, envir = ct_env)
+assign("units_of_quantity", NULL, envir = ct_env)
+assign("frequency", NULL, envir = ct_env)
 assign("customs_code", NULL, envir = ct_env)
 assign("flow_direction", NULL, envir = ct_env)
 assign("reporter", NULL, envir = ct_env)
